@@ -18,6 +18,7 @@ Options:
 
 from docopt import docopt
 import getpass
+import os
 
 from pythonanywhere.django_project import DjangoProject
 from pythonanywhere.snakesay import snakesay
@@ -26,7 +27,8 @@ from pythonanywhere.snakesay import snakesay
 def main(repo_url, domain, python_version, nuke):
     if domain == 'your-username.pythonanywhere.com':
         username = getpass.getuser().lower()
-        domain = f'{username}.pythonanywhere.com'
+        pa_domain = os.environ.get('PYTHONANYWHERE_DOMAIN', 'pythonanywhere.com')
+        domain = f'{username}.{pa_domain}'
 
     project = DjangoProject(domain, python_version)
     project.sanity_checks(nuke=nuke)
